@@ -181,7 +181,7 @@ def get_node(awsclient, node, snapshot_source, snapshot):
                     if data:
                         json_to_put.update(data) 
                 except Exception as ex:
-                    logger.info('Describe function exception: %s', ex)
+                    logger.error('Describe function exception: %s', ex)
                     db_record['error'] = 'Describe function exception: %s' % ex
             else:
                 logger.info('Invalid function exception: %s', str(function_to_call))
@@ -207,6 +207,12 @@ def _get_resources_from_list_function(response, method):
         return final_list
     elif method == 'describe_db_instances':
         return [x['DBInstanceIdentifier'] for x in response['DBInstances']]
+    elif method == 'describe_db_clusters':
+        return [x['DBClusterIdentifier'] for x in response['DBClusters']]
+    elif method == 'describe_db_parameter_groups':
+        return [x['DBParameterGroupName'] for x in response['DBParameterGroups']]
+    elif method == 'describe_global_clusters':
+        return [x['GlobalClusterIdentifier'] for x in response['GlobalClusters']]
     elif method == 'describe_load_balancers':
         return [x['LoadBalancerName'] for x in response['LoadBalancerDescriptions']]
     elif method == 'list_certificates':
@@ -235,13 +241,13 @@ def _get_resources_from_list_function(response, method):
         return response.get("TableNames")
     elif method == 'list_backups':
         return [x.get('BackupArn',"") for x in response['BackupSummaries']]
-        return response.get("TableNames")
     elif method == 'list_task_definitions':
         return response.get('taskDefinitionArns')
     elif method == 'list_clusters':
         clusters = []
         clusters.extend(response.get("clusters", []))
         clusters.extend(response.get("Clusters", []))
+        clusters.extend(response.get("clusterArns", []))
         clusters.extend([cluster["ClusterArn"] for cluster in response.get("ClusterInfoList",[])])
         logger.info("*****************%s", clusters)
         return clusters
@@ -252,7 +258,9 @@ def _get_resources_from_list_function(response, method):
     elif method == 'list_functions':
         return [x.get('FunctionName',"") for x in response['Functions']]
     elif method == 'describe_clusters':
-        return [x.get('ClusterIdentifier',"") for x in response['Clusters']]
+        clusters = []
+        clusters.extend([x.get('ClusterIdentifier', x.get("ClusterName", "")) for x in response['Clusters']])
+        return clusters
     elif method == 'list_topics':
         return [x.get('TopicArn',"") for x in response['Topics']]
     elif method == 'list_subscriptions':
@@ -285,6 +293,50 @@ def _get_resources_from_list_function(response, method):
         return [x.get("Name") for x in response['WebACLs']]
     elif method == 'describe_repositories':
         return [x.get("repositoryName") for x in response['repositories']]
+    elif method == 'list_ledgers':
+        return [x.get("Name") for x in response['Ledgers']]
+    elif method == 'describe_db_cluster_parameter_groups':
+        return [x.get("DBClusterParameterGroupName") for x in response['DBClusterParameterGroups']]
+    elif method == 'list_work_groups':
+        return [x.get("Name") for x in response['WorkGroups']]
+    elif method == 'list_databases':
+        return [x.get("DatabaseName") for x in response['Databases']]
+    elif method == 'describe_endpoints':
+        return [x.get("EndpointIdentifier") for x in response['Endpoints']]
+    elif method == 'describe_security_groups':
+        return [x.get("GroupId") for x in response['SecurityGroups']]
+    elif method == 'list_secrets':
+        return [x.get("Name") for x in response['SecretList']]
+    elif method == 'describe_log_groups':
+        return [x.get("logGroupName") for x in response['logGroups']]
+    elif method == 'describe_workspaces':
+        return [x.get("WorkspaceId") for x in response['Workspaces']]
+    elif method == 'get_data_catalog_encryption_settings':
+        return [""]
+    elif method == 'get_security_configurations':
+        return [x.get("Name") for x in response['SecurityConfigurations']]
+    elif method == 'describe_launch_configurations':
+        return [x.get("LaunchConfigurationName") for x in response['LaunchConfigurations']]
+    elif method == 'describe_auto_scaling_groups':
+        return [x.get("AutoScalingGroupName") for x in response['AutoScalingGroups']]
+    elif method == 'describe_configuration_aggregators':
+        return [x.get("ConfigurationAggregatorName") for x in response['ConfigurationAggregators']]
+    elif method == 'describe_configuration_recorders':
+        return [x.get("name") for x in response['ConfigurationRecorders']]
+    elif method == 'list_streams':
+        return response["StreamNames"]
+    elif method == 'list_brokers':
+        return [x.get("BrokerId") for x in response['BrokerSummaries']]
+    elif method == 'list_hosted_zones':
+        return [x.get("Id") for x in response['HostedZones']]
+    elif method == 'list_notebook_instances':
+        return [x.get("NotebookInstanceName") for x in response['NotebookInstances']]
+    elif method == 'list_projects':
+        return response["projects"]
+    elif method == 'list_pipelines':
+        return [x.get("name") for x in response['pipelines']]
+    elif method == 'list_applications':
+        return response["applications"]
     else:
         return []
 
@@ -319,6 +371,7 @@ def get_all_nodes(awsclient, node, snapshot, connector):
                 response = list_function(**list_kwargs)
                 list_of_resources = _get_resources_from_list_function(response, list_function_name)
             except Exception as ex:
+                logger.error("exception in list function: %s", ex)
                 list_of_resources = []
             detail_methods = get_field_value(node, 'detailMethods')
             for each_resource in list_of_resources:
@@ -338,6 +391,8 @@ def get_all_nodes(awsclient, node, snapshot, connector):
                 logger.info("==========storing in database%s", resource_arn)
                 db_record['arn'] = resource_arn
                 db_records.append(db_record)
+        else:
+            logger.warning("list_function %s is not callable", list_function)
 
     return db_records
 
@@ -377,6 +432,7 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
     logger.info("===================getting function kwargs=====================")
     logger.info("client_str====%s", client_str)
     logger.info("function_name====%s", function_name)
+    logger.info("arn_str====%s", arn_str)
     logger.info("resource_id====%s==>%s", type(resource_id),resource_id)
     if client_str == "s3":
         return {'Bucket' : resource_id}
@@ -385,6 +441,18 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
         return {
             'DBInstanceIdentifier': resource_id
         }
+    elif client_str == "rds" and function_name in ["describe_db_clusters"]:
+        return {
+            'DBClusterIdentifier': resource_id
+        }
+    elif client_str == "rds" and function_name in ["describe_db_parameters"]:
+        return {
+            'DBParameterGroupName': resource_id
+        }
+    elif client_str == "rds" and function_name in ["describe_global_clusters"]:
+        return {
+            'GlobalClusterIdentifier': resource_id
+        }
     elif client_str == "ec2" and function_name == "describe_instance_attribute":
         return {
             'Attribute': 'instanceType'|'kernel'|'ramdisk'|'userData'|'disableApiTermination'|'instanceInitiatedShutdownBehavior'|'rootDeviceName'|'blockDeviceMapping'|'productCodes'|'sourceDestCheck'|'groupSet'|'ebsOptimized'|'sriovNetSupport'|'enaSupport'|'enclaveOptions',
@@ -411,13 +479,8 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
             'VolumeIds': [volumeid]
         }
     elif client_str == "ec2" and function_name == "describe_security_groups":
-        try:
-            groups = existing_json['Reservations'][0]['Instances'][0]['SecurityGroups']
-            groupsidlist = [x['GroupId'] for x in groups]
-        except:
-            groupsidlist = []
         return {
-            'GroupIds': groupsidlist
+            'GroupIds': [resource_id]
         }
     elif client_str == "ec2" and function_name == "describe_vpcs":
         try:
@@ -520,7 +583,7 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
         return {
             'KeyId': resource_id
         }
-    elif client_str == "dynamodb" and function_name == "describe_table":
+    elif client_str == "dynamodb" and function_name in ["describe_table", "describe_continuous_backups", "describe_kinesis_streaming_destination"]:
         return {
             'TableName': resource_id
         }
@@ -532,6 +595,14 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
         return {
             'taskDefinition': resource_id
         }
+    elif client_str == "ecs" and function_name == "describe_clusters":
+        return {
+            'clusters': [arn_str]
+        }
+    elif client_str == "ecs" and function_name == "describe_services":
+        return {
+            'services': [arn_str]
+        }
     elif client_str == "eks" and function_name == "describe_cluster":
         return {
             'name': resource_id
@@ -643,6 +714,78 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
         return {
             "repositoryName": resource_id
         }
+    elif client_str == "dax" and function_name == "describe_clusters":
+        return {
+            'ClusterNames': [resource_id]
+        }
+    elif client_str == "qldb" and function_name == "describe_ledger":
+        return {
+            'Name': resource_id
+        }
+    elif client_str == "docdb" and function_name == "describe_db_cluster_parameters":
+        return {
+            'DBClusterParameterGroupName': resource_id
+        }
+    elif client_str == "athena" and function_name == "get_work_group":
+        return {
+            'WorkGroup': resource_id
+        }
+    elif client_str == "logs" and function_name == "describe_log_groups":
+        return {
+            'logGroupNamePrefix': resource_id
+        }
+    elif client_str == "workspaces" and function_name == "describe_workspaces":
+        return {
+            'WorkspaceIds': [resource_id]
+        }
+    elif client_str == "glue" and function_name == "get_security_configuration":
+        return {
+            'Name': resource_id
+        }
+    elif client_str == "autoscaling" and function_name == "describe_launch_configurations":
+        return {
+            'LaunchConfigurationNames': [resource_id]
+        }
+    elif client_str == "autoscaling" and function_name == "describe_auto_scaling_groups":
+        return {
+            'AutoScalingGroupNames': [resource_id]
+        }
+    elif client_str == "config" and function_name == "describe_configuration_aggregators":
+        return {
+            'ConfigurationAggregatorNames': [resource_id]
+        }
+    elif client_str == "config" and function_name == "describe_configuration_recorders":
+        return {
+            'ConfigurationRecorderNames': [resource_id]
+        }
+    elif client_str == "kinesis" and function_name == "describe_stream":
+        return {
+            'StreamName': resource_id
+        }
+    elif client_str == "mq" and function_name == "describe_broker":
+        return {
+            'BrokerId': resource_id
+        }
+    elif client_str == "route53" and function_name == "list_resource_record_sets":
+        return {
+            'HostedZoneId': resource_id
+        }
+    elif client_str == "sagemaker" and function_name == "describe_notebook_instance":
+        return {
+            'NotebookInstanceName': resource_id
+        }
+    elif client_str == "codebuild" and function_name == "batch_get_projects":
+        return {
+            'names': [resource_id]
+        }
+    elif client_str == "codepipeline" and function_name == "get_pipeline":
+        return {
+            'name': resource_id
+        }
+    elif client_str == "codedeploy" and function_name == "batch_get_applications":
+        return {
+            'applicationNames': [resource_id]
+        }
     else:
         return {}
 
@@ -732,7 +875,7 @@ def populate_aws_snapshot(snapshot, container=None):
                     client_str, aws_region = _get_aws_client_data_from_node(node,
                         default_client=connector_client_str, default_region=region)
                     if not _validate_client_name(client_str):
-                        logger.error("Invalid Client Name")
+                        logger.error("Invalid Client Name: %s", client_str)
                         return snapshot_data
                     try:
                         awsclient = client(client_str.lower(), aws_access_key_id=access_key,
@@ -799,6 +942,7 @@ def populate_aws_snapshot(snapshot, container=None):
                         logger.info(awsclient)
                         if awsclient:
                             all_data = get_all_nodes(awsclient, node, snapshot, sub_data)
+                            logger.info("all_data: %s", all_data)
                             if all_data:
                                 for data in all_data:
                                     snapshot_data[node['masterSnapshotId']].append(
